// ======================================================================
//
// MaterialData_wu2.cpp
// jeff grills
//
// copyright 1998 origin sytems inc
//
// ======================================================================

#include "first.h"
#include "MaterialData_wu2.h"

#include "gl_wu2.h"
#include "Material.h"
#include "PaletteData_wu2.h"
#include "Palette.h"

#include "clut.h"
#include "raster.h"

// ======================================================================

MaterialData_wu2::MaterialData_wu2(int r, int g, int b)
{
	init();

	RGB rgb1;

	rgb1.r = static_cast<u_int8>(r);
	rgb1.g = static_cast<u_int8>(g);
	rgb1.b = static_cast<u_int8>(b);

	// build the surface description
	solidSurfaceDesc = NEW raster::solid_surface_desc;
	solidSurfaceDesc->shade_bits = GL_wu2::getShadeBits();
	GL_wu2::makeClut(&rgb1, 1, &clut, &solidSurfaceDesc->clut);
}

// ----------------------------------------------------------------------

MaterialData_wu2::MaterialData_wu2(const StaticMaterial *material)
{
	init();

	const Pixel8 * const rgb = material->getRGBMap8();
	const Pixel8 * const alpha = material->getAlphaMap();

	if (rgb == NULL && alpha == NULL)
	{
		RGB rgb1;

		rgb1.r = material->getR();
		rgb1.g = material->getG();
		rgb1.b = material->getB();

		// build the surface description
		solidSurfaceDesc = NEW raster::solid_surface_desc;
		solidSurfaceDesc->shade_bits = GL_wu2::getShadeBits();
		GL_wu2::makeClut(&rgb1, 1, &clut, &solidSurfaceDesc->clut);

		return;
	}

	if (rgb == NULL && alpha != NULL)
		return;

	// build the texture info
	texture                   = NEW raster::texture;
	texture->map              = material->getRGBMap8();
	texture->has_transparency = material->getChromakey() == StaticMaterial::ChromakeyOn;
	texture->shade_bits       = GL_wu2::getShadeBits();
	texture->clut             = static_cast<PaletteData_wu2 *>(material->getPalette()->getData())->getClut();
	texture->l2_dim[0]        = intLog2(material->getWidth());
	texture->l2_dim[1]        = intLog2(material->getHeight());

	// register the texture with the rasterizer
	raster::register_texture(texture);
}

// ----------------------------------------------------------------------

MaterialData_wu2::~MaterialData_wu2(void)
{
	delete texture;
	texture = NULL;

	delete [] clut;
	clut = NULL;

	delete solidSurfaceDesc;
	solidSurfaceDesc = NULL;
}

// ----------------------------------------------------------------------

void MaterialData_wu2::init(void)
{
	texture          = NULL;
	solidSurfaceDesc = NULL;
	clut             = NULL;
}

// ======================================================================

